==> flutter_tk-0.0.4.tar.gz: lib/tk_file.dart <==
import 'dart:io';
import 'dart:typed_data';
import 'dart:ui';

import 'package:dio/dio.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_tk/tk_config.dart';
import 'package:get/get.dart' as g;
import 'package:wechat_assets_picker/wechat_assets_picker.dart';
import 'package:wechat_camera_picker/wechat_camera_picker.dart';

class TkFile {
  static Future<List<AssetEntity>> pick({
    int max = 1,
    RequestType type = RequestType.image,
    Color color,
  }) {
    return AssetPicker.pickAssets(g.Get.context,
        maxAssets: max,
        requestType: type,
        themeColor: color ?? g.Get.theme.primaryColor,
        customItemPosition: CustomItemPosition.prepend,
        sortPathDelegate: CustomSortPathDelegate(),
        customItemBuilder: (context) {
          return GestureDetector(
            behavior: HitTestBehavior.opaque,
            onTap: () async {
              final AssetEntity result =
              await CameraPicker.pickFromCamera(
                context,
                isAllowRecording: type != RequestType.image,
                theme: ThemeData(accentColor: Colors.white70),
              );
              if (result != null) {
                Navigator.of(context).pop(<AssetEntity>[result]);
              }
            },
            child: const Center(
              child: Icon(Icons.camera_alt, size: 36.0, color: Colors.white70,),
            ),
          );
        },
    );
  }
  static Future<Uint8List> compressImage (AssetEntity image, {
    int maxSize = 1800,
  }) async {
    var ext = image.title.split('.').last.toLowerCase();
    if (ext == 'gif') return await image.originBytes;
    if (image.height >= maxSize || image.width >= maxSize || ext == 'heic') {
      var format = ext == 'png' ? ThumbFormat.png : ThumbFormat.jpeg;
      var scale = image.height >= image.width ? image.height / maxSize : image.width / maxSize;
      var height = scale > 1 ? (image.height / scale).round() : image.height;
      var width = scale > 1 ? (image.width / scale).round() : image.width;
      return await image.thumbDataWithSize(width, height,
          format: format
      );
    }
    return await image.originBytes;
  }
  static upload (AssetEntity file) async {
    if (TkConfig().uploadUrl == null) throw('必须设置uploadUrl才能上传文件');
    var data = await compressImage(file);
    FormData formData = FormData.fromMap({
      'file': MultipartFile.fromBytes(data),
    });
    Response res = await Dio().post(TkConfig().uploadUrl, data: formData);
    return res.data['url'];
  }
  static pickAndUpload ({
    int max = 1,
    RequestType type = RequestType.image,
    Color color,
  }) async {
    if (TkConfig().uploadUrl == null) throw('必须设置uploadUrl才能上传文件');
    var list = await TkFile.pick(max: max, type: type, color: color);
    if (list == null) return null;
    List<Future<dynamic>> futures = [];
    list.forEach((element) {
      futures.add(TkFile.upload(element));
    });
    return await Future.wait(futures);
  }
}
Map<String, String> assetsDirNames = {
  'Recent': '最近',
  'Live Photo': '实况照片',
  'Screenshots': '屏幕截图',
  'picture': '相册',
  'WeiXin': '微信',
  'images': '图片',
  'Camera': '照片',
  'Download': '下载',
};
class CustomSortPathDelegate extends SortPathDelegate {
  const CustomSortPathDelegate();

  @override
  void sort(List<AssetPathEntity> list) {
    for (final AssetPathEntity entity in list) {
      if (assetsDirNames.containsKey(entity.name)) {
        entity.name = assetsDirNames[entity.name];
      }
    }
  }
}

==> flutter_tk-0.1.0.tar.gz: lib/tk_file.dart <==
import 'dart:typed_data';
import 'dart:ui';

import 'package:dio/dio.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_tk/tk_config.dart';
import 'package:get/get.dart' as g;
import 'package:wechat_assets_picker/wechat_assets_picker.dart';
import 'package:wechat_camera_picker/wechat_camera_picker.dart';

class TkFile {
  static Future<List<AssetEntity>> pick({
    int max = 1,
    RequestType type = RequestType.image,
    Color color,
  }) {
    return AssetPicker.pickAssets(g.Get.context,
        maxAssets: max,
        requestType: type,
        themeColor: color ?? g.Get.theme.primaryColor,
        specialItemPosition: SpecialItemPosition.prepend,
        sortPathDelegate: CustomSortPathDelegate(),
        specialItemBuilder: (context) {
          return GestureDetector(
            behavior: HitTestBehavior.opaque,
            onTap: () async {
              final AssetEntity result =
              await CameraPicker.pickFromCamera(
                context,
                enableRecording: type != RequestType.image,
                theme: ThemeData(accentColor: Colors.white70),
              );
              if (result != null) {
                Navigator.of(context).pop(<AssetEntity>[result]);
              }
            },
            child: const Center(
              child: Icon(Icons.camera_alt, size: 36.0, color: Colors.white70,),
            ),
          );
        },
    );
  }
  static Future<Uint8List> compressImage (AssetEntity image, {
    int maxSize = 1800,
  }) async {
    var ext = image.title.split('.').last.toLowerCase();
    if (ext == 'gif') return await image.originBytes;
    if (image.height >= maxSize || image.width >= maxSize || ext == 'heic') {
      var format = ext == 'png' ? ThumbFormat.png : ThumbFormat.jpeg;
      var scale = image.height >= image.width ? image.height / maxSize : image.width / maxSize;
      var height = scale > 1 ? (image.height / scale).round() : image.height;
      var width = scale > 1 ? (image.width / scale).round() : image.width;
      return await image.thumbDataWithSize(width, height,
          format: format
      );
    }
    return await image.originBytes;
  }
  static upload (AssetEntity file) async {
    if (TkConfig().uploadUrl == null) throw('必须设置uploadUrl才能上传文件');
    var data = await compressImage(file);
    FormData formData = FormData.fromMap({
      'file': MultipartFile.fromBytes(data),
    });
    Response res = await Dio().post(TkConfig().uploadUrl, data: formData);
    return res.data['url'];
  }
  static pickAndUpload ({
    int max = 1,
    RequestType type = RequestType.image,
    Color color,
  }) async {
    if (TkConfig().uploadUrl == null) throw('必须设置uploadUrl才能上传文件');
    var list = await TkFile.pick(max: max, type: type, color: color);
    if (list == null) return null;
    List<Future<dynamic>> futures = [];
    list.forEach((element) {
      futures.add(TkFile.upload(element));
    });
    return await Future.wait(futures);
  }
}
Map<String, String> assetsDirNames = {
  'Recent': '最近',
  'Live Photo': '实况照片',
  'Screenshots': '屏幕截图',
  'picture': '相册',
  'WeiXin': '微信',
  'images': '图片',
  'Camera': '照片',
  'Download': '下载',
};
class CustomSortPathDelegate extends SortPathDelegate {
  const CustomSortPathDelegate();

  @override
  void sort(List<AssetPathEntity> list) {
    for (final AssetPathEntity entity in list) {
      if (assetsDirNames.containsKey(entity.name)) {
        entity.name = assetsDirNames[entity.name];
      }
    }
  }
}
